
const User = `
    # Utilisateurs
    type User {
        # Prénom de l'utilisateur
        givenName: String!
        # Nom de famille
        lastName: String!
        # Surnom
        nickname: String
        nationality: String
        uid: ID!
        birthdate: String!
        mail: String
        phone: String
        # Groupes dont l'utilisateur est membre.
        groups: [SimpleGroup]
        # Groupes que l'utilisateur aime.
        likes: [Group]
        # Adresse(s) de l'utilisateur.
        address: [String]
        # Promotion
        promotion: String
    }
`;

const Group = `
    # Groupes associatifs

    """
    L'interface Group représente les deux types de groupes implémentés dans Sigma : les groupes
    simples, dont les membres sont des utilisateurs, et les métagroupes, dont les membres sont
    des groupes simples (tel que Federez, dont les membres incluent le BR et DaTA). 
    """
    interface Group {
        uid: ID
        name: String
        # Site Web.
        website: String
        description: String
        
        # Jour et heure de création du groupe.
        createdAt: String!
        # Dernière mise à jour du groupe.
        updatedAt: String!

    }

    # Le groupe de base, dont les membres sont des utilisateurs : binets, Kès...
    type SimpleGroup implements Group {
        uid: ID
        name: String
        website: String
        createdAt: String!
        updatedAt: String!

        # Membres du groupe
        members: [User]
        description: String
        # École d'origine du groupe
        school: String
        # Groupe parent
        parent: Group
    }

    # Un groupe dont les membre sont d'autres groupes
    type MetaGroup implements Group {
        uid: ID
        name: String
        website: String
        createdAt: String!
        updatedAt: String!
        description: String

        # Les groupes constitutifs du méta-groupe.
        members: [Group]!
    }

`;

const Message = `
    # Tout type de message créé par un ou plusieurs groupes.
    interface Message {
        id: ID!
        # Titre du message
        title: String!
        content: String
        createdAt: String!
        updatedAt: String!
        # Auteur(s) du message
        authors: [Group]
    }

    # Publication postée par un ou plusieurs groupes.
    type Post implements Message {
        id: ID!
        title: String!
        createdAt: String!
        updatedAt: String!
        authors: [Group]
        content: String!
    }

    # Annonce publique effectuée par un ou plusieurs groupes.
    type Announcement implements Message {
        id: ID!
        title: String!
        createdAt: String!
        updatedAt: String!
        authors: [Group]
        content: String!
        importance: Int
        views: Int
        forEvent : Event
    }

    # Événements organisés par un ou plusieurs groupes.
    type Event implements Message {
        id: ID!
        # Intitulé de l'événement
        title: String!
        # Lieu de l'événement
        location: String
        createdAt: String!
        updatedAt: String!
        startTime: String!
        endTime: String!
        # Organisateurs
        authors: [Group]
        # Personnes qui participent à l'événement.
        participatingGroups: [Group]
        participatingUsers: [User]
        content: String
        asAnnouncement : Announcement
    }
`;

const Requests = `

    interface Request {
        # ID de la demande
        id: ID!
        # message accompagnant la demande
        message: String
    }

    # Demande d'un utilisateur désirant rejoindre le groupe.
    type UserJoinGroup implements Request{
        id: ID!
        message: String
        # Émetteur de la demande
        user: User
    }


    # Demande d'un groupe voulant rejoindre un événement
    type GroupJoinEvent implements Request{
        id: ID!
        message: String
        # Événement concerné
        event: Event
        # Groupe voulant rejoindre l'événement
        groupWantingToJoin: Group
    }

    # Demande au récipiendaire de rejoindre l'organisation d'un événement.
    type YourGroupHostEvent implements Request{
        id: ID!
        message: String
        # Événement concerné
        event: Event
        # Groupe ayant publié l'évènement et lancé l'invitation
        sender: Group
    }

`;

const objectDefs = [Group, User, Message, Requests];
export default objectDefs;